
Example Project
===============
This is an example project that is used to demonstrate how to publish
Python packages on PyPI.

Installing
============

.. code-block:: bash

    pip install yw_hello

Usage
=====

.. code-block:: bash

    >>> from yw_hello import yw_hello
    >>> yw_hello('Fizz Buzz')
    Hello FizzBuzz!